@@ -274,7 +274,6 @@ entry_activated (GtkWidget *widget, gpointer data)
 	}
 
 	g_signal_emit (gentry, gnome_entry_signals[ACTIVATE_SIGNAL], 0);
-	gnome_entry_save_history (gentry);
 }
 
 static void
@@ -435,6 +434,15 @@ gnome_entry_history_changed (GConfClient* client,
 }
 
 /* FIXME: Make this static */
+
+/**
+ * gnome_entry_set_history_id
+ * @gentry: Pointer to GnomeEntry object.
+ * @history_id: the text id under which history data is stored
+ *
+ * Description: Set the id of the history list. This function cannot be
+ * used to change and already existing id.
+ */
 void
 gnome_entry_set_history_id (GnomeEntry *gentry, const gchar *history_id)
 {
@@ -442,8 +450,15 @@ gnome_entry_set_history_id (GnomeEntry *gentry, const gchar *history_id)
 
 	g_return_if_fail (gentry != NULL);
 	g_return_if_fail (GNOME_IS_ENTRY (gentry));
-	g_return_if_fail (gentry->_priv->history_id == NULL);
 
+	if (gentry->_priv->history_id != NULL) {
+		g_warning ("The program is trying to change an existing "
+			   "GnomeEntry history id. This operation is "
+			   "not allowed.");
+
+		return;
+	}
+				
 	if (history_id == NULL)
 		return;
 
@@ -493,11 +508,9 @@ gnome_entry_get_history_id (GnomeEntry *gentry)
  * @max_saved: Maximum number of history items to save
  *
  * Description: Set internal limit on number of history items saved
- * to the config file, when #gnome_entry_save_history() is called.
+ * to the config file.
  * Zero is an acceptable value for @max_saved, but the same thing is
  * accomplished by setting the history id of @gentry to %NULL.
- *
- * Returns:
  */
 void
 gnome_entry_set_max_saved (GnomeEntry *gentry, guint max_saved)
@@ -513,7 +526,7 @@ gnome_entry_set_max_saved (GnomeEntry *gentry, guint max_saved)
  * @gentry: Pointer to GnomeEntry object.
  *
  * Description: Get internal limit on number of history items saved
- * to the config file, when #gnome_entry_save_history() is called.
+ * to the config file
  * See #gnome_entry_set_max_saved().
  *
  * Returns: An unsigned integer
@@ -593,6 +606,8 @@ gnome_entry_add_history (GnomeEntry *gentry, gboolean save,
 {
 	GnomeEntryPrivate *priv;
 	struct item *item;
+	GList *list;
+	gboolean changed;
 
 	g_return_if_fail (gentry != NULL);
 	g_return_if_fail (GNOME_IS_ENTRY (gentry));
@@ -604,12 +619,36 @@ gnome_entry_add_history (GnomeEntry *gentry, gboolean save,
 	item->save = save;
 	item->text = g_strdup (text);
 
+	/* Remove duplicates */
+	changed = FALSE;
+	list = priv->items;
+	
+	while (list != NULL) {
+		struct item * data = list->data;
+			
+		if (strcmp (data->text, text) == 0) {
+			free_item (data, NULL);
+			priv->items = g_list_delete_link (priv->items, list);
+			
+			changed = TRUE;
+			break;
+		}
+
+		list = g_list_next (list);
+	}
+
+	/* Really add the history item */
 	if (append)
 		priv->items = g_list_append (priv->items, item);
 	else
 		priv->items = g_list_prepend (priv->items, item);
 
+	/* Update combo list */
 	set_combo_items (gentry);
+
+	/* Save the history if needed */
+	if (changed || save)
+		gnome_entry_save_history (gentry);
 }
 
 
@@ -624,14 +663,18 @@ gnome_entry_add_history (GnomeEntry *gentry, gboolean save,
  * the history list inside @gentry.  If @save is %TRUE, the history
  * item will be saved in the config file (assuming that @gentry's
  * history id is not %NULL).
- *
- * Returns:
+ * Duplicates are automatically removed from the history list.
+ * The history list is automatically saved if needed.
  */
 void
 gnome_entry_prepend_history (GnomeEntry *gentry, gboolean save,
 			     const gchar *text)
 {
-  gnome_entry_add_history (gentry, save, text, FALSE);
+	g_return_if_fail (gentry != NULL);
+	g_return_if_fail (GNOME_IS_ENTRY (gentry));
+	g_return_if_fail (text != NULL); /* FIXME: should we just return without warning? */
+	
+	gnome_entry_add_history (gentry, save, text, FALSE);
 }
 
 
@@ -645,13 +688,17 @@ gnome_entry_prepend_history (GnomeEntry *gentry, gboolean save,
  * of the history list inside @gentry.  If @save is %TRUE, the
  * history item will be saved in the config file (assuming that
  * @gentry's history id is not %NULL).
- *
- * Returns:
+ * Duplicates are automatically removed from the history list.
+ * The history list is automatically saved if needed.
  */
 void
 gnome_entry_append_history (GnomeEntry *gentry, gboolean save,
 			    const gchar *text)
 {
+	g_return_if_fail (gentry != NULL);
+	g_return_if_fail (GNOME_IS_ENTRY (gentry));
+	g_return_if_fail (text != NULL); /* FIXME: should we just return without warning? */
+
 	gnome_entry_add_history (gentry, save, text, TRUE);
 }
 
@@ -670,7 +717,7 @@ gnome_entry_load_history (GnomeEntry *gentry)
 	    gentry->_priv->history_id == NULL)
 		return;
 
-	g_assert (gentry->_priv->gconf_client != NULL);
+	g_return_if_fail (gentry->_priv->gconf_client != NULL);
 
 	free_items (gentry);
 
@@ -698,10 +745,7 @@ gnome_entry_load_history (GnomeEntry *gentry)
  * gnome_entry_clear_history
  * @gentry: Pointer to GnomeEntry object.
  *
- * Description:  Clears the history, you should call #gnome_entry_save_history
- * To make the change permanent.
- *
- * Returns:
+ * Description:  Clears the history.
  */
 void
 gnome_entry_clear_history (GnomeEntry *gentry)
@@ -712,6 +756,8 @@ gnome_entry_clear_history (GnomeEntry *gentry)
 	free_items (gentry);
 
 	set_combo_items (gentry);
+
+	gnome_entry_save_history (gentry);
 }
 
 static gboolean
@@ -746,7 +792,7 @@ gnome_entry_save_history (GnomeEntry *gentry)
 	    gentry->_priv->history_id == NULL)
 		return;
 
-	g_assert (gentry->_priv->gconf_client != NULL);
+	g_return_if_fail (gentry->_priv->gconf_client != NULL);
 
 	key = build_gconf_key (gentry);
 	gconf_items = NULL;
@@ -841,10 +887,66 @@ get_position (GtkEditable    *editable)
 	return gtk_editable_get_position (GTK_EDITABLE (entry));
 }
 
+/* Copied from gtkentry */
+static void
+do_insert_text (GtkEditable *editable,
+		const gchar *new_text,
+		gint         new_text_length,
+		gint        *position)
+{
+	GtkEntry *entry = GTK_ENTRY (gnome_entry_gtk_entry (GNOME_ENTRY (editable)));
+	gchar buf[64];
+	gchar *text;
+
+	if (*position < 0 || *position > entry->text_length)
+		*position = entry->text_length;
+
+	g_object_ref (G_OBJECT (editable));
+
+	if (new_text_length <= 63)
+		text = buf;
+	else
+		text = g_new (gchar, new_text_length + 1);
+
+	text[new_text_length] = '\0';
+	strncpy (text, new_text, new_text_length);
+
+	g_signal_emit_by_name (editable, "insert_text", text, new_text_length, position);
+
+	if (new_text_length > 63)
+		g_free (text);
+
+	g_object_unref (G_OBJECT (editable));
+}
+
+/* Copied from gtkentry */
+static void
+do_delete_text (GtkEditable *editable,
+		gint         start_pos,
+		gint         end_pos)
+{
+	GtkEntry *entry = GTK_ENTRY (gnome_entry_gtk_entry (GNOME_ENTRY (editable)));
+
+	if (end_pos < 0 || end_pos > entry->text_length)
+		end_pos = entry->text_length;
+	if (start_pos < 0)
+		start_pos = 0;
+	if (start_pos > end_pos)
+		start_pos = end_pos;
+
+	g_object_ref (G_OBJECT (editable));
+
+	g_signal_emit_by_name (editable, "delete_text", start_pos, end_pos);
+
+	g_object_unref (G_OBJECT (editable));
+}
+
 static void
 gnome_entry_editable_init (GtkEditableClass *iface)
 {
 	/* Just proxy to the GtkEntry */
+	iface->do_insert_text = do_insert_text;
+	iface->do_delete_text = do_delete_text;
 	iface->insert_text = insert_text;
 	iface->delete_text = delete_text;
 	iface->get_chars = get_chars;
